@@ -125,13 +125,13 @@ class ReadRequest:
     warehouse: str
     universe: Universe
 
+    pointers: typing.Dict[str, str]
+
     effective_dating: typing.Union[
         typing.Tuple[datetime.datetime, datetime.datetime],
         typing.List[typing.Tuple[datetime.datetime, datetime.datetime, str]],
         datetime.datetime
-    ]
-
-    pointers: typing.Dict[str, str]
+    ] = None
 
     valid_dating: typing.Union[
         typing.Tuple[datetime.datetime, datetime.datetime],
@@ -156,6 +156,16 @@ class ReadRequest:
 
     modifiers: typing.List[Modifier] = None
 
+    def get_derived_effective_start_dt(self) -> datetime.datetime:
+        if self.effective_dating is not None:
+            return self.get_min_effective_dt()
+        return self.get_min_valid_dt()
+
+    def get_derived_effective_end_dt(self) -> datetime.datetime:
+        if self.effective_dating is not None:
+            return self.get_max_effective_dt()
+        return self.get_max_valid_dt()
+
     def get_resolved_effective_dating(self) -> typing.List[datetime.datetime]:
         return flatten_date_constraints(self.effective_dating)
 
@@ -168,6 +178,12 @@ class ReadRequest:
     def get_max_effective_dt(self) -> datetime.datetime:
         return max(self.get_resolved_effective_dating())
 
+    def get_min_valid_dt(self) -> datetime.datetime:
+        return min(self.get_resolved_valid_dating())
+
+    def get_max_valid_dt(self) -> datetime.datetime:
+        return max(self.get_resolved_valid_dating())
+
 
 @dataclass
 class ReadUniverseRequest:
