@@ -186,6 +186,21 @@ class Descriptor:
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
 
+    @property
+    def payload_hash(self) -> int:
+        components = [
+            hash(self.attribute),
+            hash(self.value),
+            hash(self.effective_start_dt),
+            hash(self.effective_end_dt),
+            hash(self.valid_start_dt),
+            hash(self.valid_end_dt),
+            hash(self.knowledge_start_dt),
+            hash(self.knowledge_end_dt),
+        ]
+
+        return hash(frozenset(sorted(components)))
+
     def to_proto(self) -> PDescriptor:
         return PDescriptor(
             attribute_code=self.attribute,
@@ -204,6 +219,15 @@ class Entity:
     identity: Identity
     descriptors: typing.List[Descriptor]
 
+    @property
+    def payload_hash(self) -> int:
+        components = [self.identity.uid]
+
+        for d in self.descriptors:
+            components.append(d.payload_hash)
+
+        return hash(frozenset(sorted(components)))
+
     def to_proto(self) -> EntityEntry:
         return EntityEntry(
             identity=self.identity.to_proto(),
@@ -219,6 +243,19 @@ class Relationship:
     effective_start_dt: datetime.datetime
     effective_end_dt: datetime.datetime
 
+    @property
+    def payload_hash(self) -> int:
+
+        components = [
+            hash(self.source_identity_uid),
+            hash(self.target_identity_uid),
+            hash(self.relationship_type),
+            hash(self.effective_start_dt),
+            hash(self.effective_end_dt),
+        ]
+
+        return hash(frozenset(sorted(components)))
+
     def to_proto(self) -> RelationshipEntry:
         return RelationshipEntry(
             source_identity_uid=self.source_identity_uid,
